@@ -56,6 +56,7 @@ type ApplyConfigProvider interface {
 
 	DetailedExitcode() bool
 
+	Color() bool
 	NoColor() bool
 	Context() int
 	DiffOutput() string
@@ -65,9 +66,7 @@ type ApplyConfigProvider interface {
 	SkipCleanup() bool
 	SkipDiffOnInstall() bool
 
-	SkipNeeds() bool
-	IncludeNeeds() bool
-	IncludeTransitiveNeeds() bool
+	DAGConfig
 
 	concurrencyConfig
 	interactive
@@ -84,9 +83,12 @@ type SyncConfigProvider interface {
 	Wait() bool
 	WaitForJobs() bool
 
+	Validate() bool
+
 	SkipNeeds() bool
 	IncludeNeeds() bool
 	IncludeTransitiveNeeds() bool
+	DAGConfig
 
 	concurrencyConfig
 	loggingConfig
@@ -109,10 +111,10 @@ type DiffConfigProvider interface {
 	SuppressDiff() bool
 	SkipDiffOnInstall() bool
 
-	SkipNeeds() bool
-	IncludeNeeds() bool
+	DAGConfig
 
 	DetailedExitcode() bool
+	Color() bool
 	NoColor() bool
 	Context() int
 	DiffOutput() string
@@ -160,6 +162,8 @@ type LintConfigProvider interface {
 	SkipDeps() bool
 	SkipCleanup() bool
 
+	DAGConfig
+
 	concurrencyConfig
 }
 
@@ -182,12 +186,18 @@ type TemplateConfigProvider interface {
 	SkipTests() bool
 	OutputDir() string
 	IncludeCRDs() bool
-	IncludeNeeds() bool
-	IncludeTransitiveNeeds() bool
+
+	DAGConfig
 
 	concurrencyConfig
 }
 
+type DAGConfig interface {
+	SkipNeeds() bool
+	IncludeNeeds() bool
+	IncludeTransitiveNeeds() bool
+}
+
 type WriteValuesConfigProvider interface {
 	Values() []string
 	Set() []string
