@@ -1,6 +1,6 @@
 package app
 
-import "github.com/roboll/helmfile/pkg/helmexec"
+import "github.com/helmfile/helmfile/pkg/helmexec"
 
 type noCallHelmExec struct {
 }
