@@ -2,14 +2,13 @@ package app
 
 import (
 	"fmt"
-	"io/ioutil"
 	"os"
 	"sort"
 	"strings"
 
-	"github.com/roboll/helmfile/pkg/argparser"
-	"github.com/roboll/helmfile/pkg/helmexec"
-	"github.com/roboll/helmfile/pkg/state"
+	"github.com/helmfile/helmfile/pkg/argparser"
+	"github.com/helmfile/helmfile/pkg/helmexec"
+	"github.com/helmfile/helmfile/pkg/state"
 )
 
 type Run struct {
@@ -52,7 +51,7 @@ func (r *Run) withPreparedCharts(helmfileCommand string, opts state.ChartPrepare
 	// Create tmp directory and bail immediately if it fails
 	var dir string
 	if len(opts.OutputDir) == 0 {
-		tempDir, err := ioutil.TempDir("", "helmfile*")
+		tempDir, err := os.MkdirTemp("", "helmfile*")
 		if err != nil {
 			return err
 		}
@@ -81,8 +80,11 @@ func (r *Run) withPreparedCharts(helmfileCommand string, opts state.ChartPrepare
 			Namespace:   rel.Namespace,
 			KubeContext: rel.KubeContext,
 		}
-		if chart := releaseToChart[key]; chart != "" {
-			rel.Chart = chart
+		if chart := releaseToChart[key]; chart != rel.Chart {
+			// In this case we assume that the chart is downloaded and modified by Helmfile and chartify.
+			// So we take note of the local filesystem path to the modified version of the chart
+			// and use it later via the Release.ChartPathOrName() func.
+			rel.ChartPath = chart
 		}
 	}
 
