@@ -4,7 +4,7 @@ import (
 	"fmt"
 	"strings"
 
-	"github.com/roboll/helmfile/pkg/state"
+	"github.com/helmfile/helmfile/pkg/state"
 )
 
 type keyVal struct {
@@ -13,12 +13,16 @@ type keyVal struct {
 	spaceFlag bool
 }
 type argMap struct {
-	//m map[string]string
 	m     map[string][]*keyVal
 	flags []string
 }
 
+// SetArg sets a flag and value in the map
 func (a *argMap) SetArg(flag, arg string, isSpace bool) {
+	// if flag is empty, return
+	if len(flag) == 0 {
+		return
+	}
 	if _, exists := a.m[flag]; !exists {
 		keyarg := &keyVal{key: flag, val: arg, spaceFlag: isSpace}
 		a.m[flag] = append(a.m[flag], keyarg)
@@ -29,6 +33,7 @@ func (a *argMap) SetArg(flag, arg string, isSpace bool) {
 	}
 }
 
+// newArgMap creates a new argMap
 func newArgMap() *argMap {
 	return &argMap{m: map[string][]*keyVal{}}
 }
