@@ -4,7 +4,7 @@ import (
 	"bytes"
 	"fmt"
 	"io"
-	"io/ioutil"
+	"net/url"
 	"os"
 	"path/filepath"
 	"strconv"
@@ -12,6 +12,7 @@ import (
 	"sync"
 
 	"github.com/Masterminds/semver/v3"
+	"github.com/helmfile/helmfile/pkg/envvar"
 	"go.uber.org/zap"
 	"go.uber.org/zap/zapcore"
 )
@@ -65,7 +66,7 @@ func parseHelmVersion(versionStr string) (semver.Version, error) {
 	}
 
 	// Support explicit helm3 opt-in via environment variable
-	if os.Getenv("HELMFILE_HELM3") != "" && ver.Major() < 3 {
+	if os.Getenv(envvar.Helm3) != "" && ver.Major() < 3 {
 		return *semver.MustParse("v3.0.0"), nil
 	}
 
@@ -83,6 +84,14 @@ func getHelmVersion(helmBinary string, runner Runner) (semver.Version, error) {
 	return parseHelmVersion(string(outBytes))
 }
 
+func redactedUrl(chart string) string {
+	chartUrl, err := url.ParseRequestURI(chart)
+	if err != nil {
+		return chart
+	}
+	return chartUrl.Redacted()
+}
+
 // New for running helm commands
 func New(helmBinary string, logger *zap.SugaredLogger, kubeContext string, runner Runner) *execer {
 	// TODO: proper error handling
@@ -197,7 +206,7 @@ func (helm *execer) UpdateDeps(chart string) error {
 }
 
 func (helm *execer) SyncRelease(context HelmContext, name, chart string, flags ...string) error {
-	helm.logger.Infof("Upgrading release=%v, chart=%v", name, chart)
+	helm.logger.Infof("Upgrading release=%v, chart=%v", name, redactedUrl(chart))
 	preArgs := context.GetTillerlessArgs(helm)
 	env := context.getTillerlessEnv()
 
@@ -293,7 +302,7 @@ func (helm *execer) DecryptSecret(context HelmContext, name string, flags ...str
 			decFilename = absPath + decSuffix
 		}
 
-		secretBytes, err := ioutil.ReadFile(decFilename)
+		secretBytes, err := os.ReadFile(decFilename)
 		if err != nil {
 			secret.err = err
 			return "", err
@@ -323,10 +332,11 @@ func (helm *execer) DecryptSecret(context HelmContext, name string, flags ...str
 		tempFile = func(content []byte) (string, error) {
 			dir := filepath.Dir(name)
 			extension := filepath.Ext(name)
-			tmpFile, err := ioutil.TempFile(dir, "secret*"+extension)
+			tmpFile, err := os.CreateTemp(dir, "secret*"+extension)
 			if err != nil {
 				return "", err
 			}
+			defer tmpFile.Close()
 
 			_, err = tmpFile.Write(content)
 			if err != nil {
@@ -348,7 +358,7 @@ func (helm *execer) DecryptSecret(context HelmContext, name string, flags ...str
 }
 
 func (helm *execer) TemplateRelease(name string, chart string, flags ...string) error {
-	helm.logger.Infof("Templating release=%v, chart=%v", name, chart)
+	helm.logger.Infof("Templating release=%v, chart=%v", name, redactedUrl(chart))
 	var args []string
 	if helm.IsHelm3() {
 		args = []string{"template", name, chart}
@@ -387,9 +397,9 @@ func (helm *execer) TemplateRelease(name string, chart string, flags ...string)
 
 func (helm *execer) DiffRelease(context HelmContext, name, chart string, suppressDiff bool, flags ...string) error {
 	if context.Writer != nil {
-		fmt.Fprintf(context.Writer, "Comparing release=%v, chart=%v\n", name, chart)
+		fmt.Fprintf(context.Writer, "Comparing release=%v, chart=%v\n", name, redactedUrl(chart))
 	} else {
-		helm.logger.Infof("Comparing release=%v, chart=%v", name, chart)
+		helm.logger.Infof("Comparing release=%v, chart=%v", name, redactedUrl(chart))
 	}
 	preArgs := context.GetTillerlessArgs(helm)
 	env := context.getTillerlessEnv()
@@ -427,7 +437,7 @@ func (helm *execer) Lint(name, chart string, flags ...string) error {
 }
 
 func (helm *execer) Fetch(chart string, flags ...string) error {
-	helm.logger.Infof("Fetching %v", chart)
+	helm.logger.Infof("Fetching %v", redactedUrl(chart))
 	out, err := helm.exec(append([]string{"fetch", chart}, flags...), map[string]string{})
 	helm.info(out)
 	return err
@@ -442,7 +452,7 @@ func (helm *execer) ChartPull(chart string, flags ...string) error {
 		ociChartURLSplit := strings.Split(chart, ":")
 		ociChartURL := fmt.Sprintf("oci://%s", ociChartURLSplit[0])
 		ociChartTag := ociChartURLSplit[1]
-		tempDir, err := ioutil.TempDir("", "chart*")
+		tempDir, err := os.MkdirTemp("", "chart*")
 		if err != nil {
 			return err
 		}
