@@ -4,17 +4,26 @@ import (
 	"context"
 	"encoding/json"
 	"fmt"
+	neturl "net/url"
 	"os"
 	"path/filepath"
+	"strconv"
 	"strings"
 
 	"github.com/hashicorp/go-getter"
 	"github.com/hashicorp/go-getter/helper/url"
+	"github.com/helmfile/helmfile/pkg/envvar"
 	"go.uber.org/multierr"
 	"go.uber.org/zap"
 	"gopkg.in/yaml.v2"
 )
 
+var disableInsecureFeatures bool
+
+func init() {
+	disableInsecureFeatures, _ = strconv.ParseBool(os.Getenv(envvar.DisableInsecureFeatures))
+}
+
 func CacheDir() string {
 	dir, err := os.UserCacheDir()
 	if err != nil {
@@ -34,7 +43,7 @@ type Remote struct {
 	Getter Getter
 
 	// ReadFile is the implementation of the file reader that reads a local file from the specified path.
-	// Inject any implementation of your choice, like an im-memory impl for testing, ioutil.ReadFile for the real-world use.
+	// Inject any implementation of your choice, like an im-memory impl for testing, os.ReadFile for the real-world use.
 	ReadFile   func(string) ([]byte, error)
 	DirExists  func(string) bool
 	FileExists func(string) bool
@@ -186,7 +195,11 @@ func (r *Remote) Fetch(goGetterSrc string, cacheDirOpt ...string) (string, error
 	replacer := strings.NewReplacer(":", "", "//", "_", "/", "_", ".", "_")
 	dirKey := replacer.Replace(srcDir)
 	if len(query) > 0 {
-		paramsKey := strings.Replace(query, "&", "_", -1)
+		q, _ := neturl.ParseQuery(query)
+		if q.Has("sshkey") {
+			q.Set("sshkey", "redacted")
+		}
+		paramsKey := strings.Replace(q.Encode(), "&", "_", -1)
 		cacheKey = fmt.Sprintf("%s.%s", dirKey, paramsKey)
 	} else {
 		cacheKey = dirKey
@@ -274,6 +287,9 @@ func (g *GoGetter) Get(wd, src, dst string) error {
 }
 
 func NewRemote(logger *zap.SugaredLogger, homeDir string, readFile func(string) ([]byte, error), dirExists func(string) bool, fileExists func(string) bool) *Remote {
+	if disableInsecureFeatures {
+		panic("Remote sources are disabled due to 'DISABLE_INSECURE_FEATURES'")
+	}
 	remote := &Remote{
 		Logger:     logger,
 		Home:       homeDir,
