@@ -2,7 +2,6 @@ package state
 
 import (
 	"fmt"
-	"io/ioutil"
 	"os"
 	"path/filepath"
 	"sort"
@@ -10,9 +9,9 @@ import (
 
 	"github.com/Masterminds/semver/v3"
 	goversion "github.com/hashicorp/go-version"
+	"github.com/helmfile/helmfile/pkg/app/version"
+	"github.com/helmfile/helmfile/pkg/helmexec"
 	"github.com/r3labs/diff"
-	"github.com/roboll/helmfile/pkg/app/version"
-	"github.com/roboll/helmfile/pkg/helmexec"
 	"go.uber.org/zap"
 	"gopkg.in/yaml.v2"
 )
@@ -273,8 +272,8 @@ type chartDependencyManager struct {
 func NewChartDependencyManager(name string, logger *zap.SugaredLogger) *chartDependencyManager {
 	return &chartDependencyManager{
 		Name:      name,
-		readFile:  ioutil.ReadFile,
-		writeFile: ioutil.WriteFile,
+		readFile:  os.ReadFile,
+		writeFile: os.WriteFile,
 		logger:    logger,
 	}
 }
