@@ -7,12 +7,12 @@ import (
 	"io"
 	"os"
 
-	"github.com/roboll/helmfile/pkg/helmexec"
-	"github.com/roboll/helmfile/pkg/remote"
+	"github.com/helmfile/helmfile/pkg/helmexec"
+	"github.com/helmfile/helmfile/pkg/remote"
 
+	"github.com/helmfile/helmfile/pkg/environment"
+	"github.com/helmfile/helmfile/pkg/maputil"
 	"github.com/imdario/mergo"
-	"github.com/roboll/helmfile/pkg/environment"
-	"github.com/roboll/helmfile/pkg/maputil"
 	"github.com/variantdev/vals"
 	"go.uber.org/zap"
 	"gopkg.in/yaml.v2"
@@ -90,11 +90,9 @@ func (c *StateCreator) Parse(content []byte, baseDir, file string) (*HelmState,
 	state.basePath = baseDir
 
 	decoder := yaml.NewDecoder(bytes.NewReader(content))
-	if !c.Strict {
-		decoder.SetStrict(false)
-	} else {
-		decoder.SetStrict(true)
-	}
+
+	decoder.SetStrict(c.Strict)
+
 	i := 0
 	for {
 		i++
