@@ -1,26 +1,24 @@
 package state
 
 import (
-	"io/ioutil"
 	"os"
 	"path/filepath"
 	"reflect"
 	"testing"
 
-	"github.com/roboll/helmfile/pkg/environment"
-	"github.com/roboll/helmfile/pkg/remote"
+	"github.com/helmfile/helmfile/pkg/environment"
+	"github.com/helmfile/helmfile/pkg/remote"
 
-	"github.com/roboll/helmfile/pkg/testhelper"
+	"github.com/helmfile/helmfile/pkg/testhelper"
 	"go.uber.org/zap"
 
-	. "gotest.tools/v3/assert"
-	"gotest.tools/v3/assert/cmp"
+	"github.com/stretchr/testify/require"
 )
 
 func createFromYaml(content []byte, file string, env string, logger *zap.SugaredLogger) (*HelmState, error) {
 	c := &StateCreator{
 		logger:   logger,
-		readFile: ioutil.ReadFile,
+		readFile: os.ReadFile,
 		abs:      filepath.Abs,
 
 		DeleteFile: os.Remove,
@@ -336,13 +334,13 @@ func TestReadFromYaml_FilterReleasesOnLabels(t *testing.T) {
 		filter  LabelFilter
 		results []bool
 	}{
-		{LabelFilter{positiveLabels: [][]string{[]string{"tier", "frontend"}}},
+		{LabelFilter{positiveLabels: [][]string{{"tier", "frontend"}}},
 			[]bool{true, true, false}},
-		{LabelFilter{positiveLabels: [][]string{[]string{"tier", "frontend"}, []string{"foo", "bar"}}},
+		{LabelFilter{positiveLabels: [][]string{{"tier", "frontend"}, {"foo", "bar"}}},
 			[]bool{true, false, false}},
-		{LabelFilter{negativeLabels: [][]string{[]string{"tier", "frontend"}}},
+		{LabelFilter{negativeLabels: [][]string{{"tier", "frontend"}}},
 			[]bool{false, false, true}},
-		{LabelFilter{positiveLabels: [][]string{[]string{"tier", "frontend"}}, negativeLabels: [][]string{[]string{"foo", "bar"}}},
+		{LabelFilter{positiveLabels: [][]string{{"tier", "frontend"}}, negativeLabels: [][]string{{"foo", "bar"}}},
 			[]bool{false, true, false}},
 	}
 	state, err := createFromYaml(yamlContent, yamlFile, DefaultEnv, logger)
@@ -377,13 +375,13 @@ func TestReadFromYaml_FilterNegatives(t *testing.T) {
 		filter  LabelFilter
 		results []bool
 	}{
-		{LabelFilter{positiveLabels: [][]string{[]string{"stage", "pre"}}},
+		{LabelFilter{positiveLabels: [][]string{{"stage", "pre"}}},
 			[]bool{true, false, false}},
-		{LabelFilter{positiveLabels: [][]string{[]string{"stage", "post"}}},
+		{LabelFilter{positiveLabels: [][]string{{"stage", "post"}}},
 			[]bool{false, true, false}},
-		{LabelFilter{negativeLabels: [][]string{[]string{"stage", "pre"}, []string{"stage", "post"}}},
+		{LabelFilter{negativeLabels: [][]string{{"stage", "pre"}, {"stage", "post"}}},
 			[]bool{false, false, true}},
-		{LabelFilter{negativeLabels: [][]string{[]string{"foo", "bar"}}},
+		{LabelFilter{negativeLabels: [][]string{{"foo", "bar"}}},
 			[]bool{false, true, true}},
 	}
 	state, err := createFromYaml(yamlContent, yamlFile, DefaultEnv, logger)
@@ -487,6 +485,6 @@ func TestReadFromYaml_Helmfiles_Selectors(t *testing.T) {
 				t.Error("unexpected error:", err)
 			}
 		}
-		Assert(t, cmp.DeepEqual(st.Helmfiles, test.helmfiles), "for path %v", test.path)
+		require.Equalf(t, test.helmfiles, st.Helmfiles, "for path %s", test.path)
 	}
 }
