@@ -3,7 +3,7 @@ package state
 import (
 	"fmt"
 
-	"github.com/roboll/helmfile/pkg/tmpl"
+	"github.com/helmfile/helmfile/pkg/tmpl"
 	"gopkg.in/yaml.v2"
 )
 
