@@ -2,16 +2,15 @@ package state
 
 import (
 	"fmt"
-	"io/ioutil"
 	"os"
 	"path/filepath"
 	"reflect"
 	"testing"
 
 	"github.com/Masterminds/semver/v3"
-	"github.com/roboll/helmfile/pkg/exectest"
-	"github.com/roboll/helmfile/pkg/helmexec"
-	"github.com/roboll/helmfile/pkg/testhelper"
+	"github.com/helmfile/helmfile/pkg/exectest"
+	"github.com/helmfile/helmfile/pkg/helmexec"
+	"github.com/helmfile/helmfile/pkg/testhelper"
 	"github.com/variantdev/vals"
 )
 
@@ -32,9 +31,9 @@ func TestLabelParsing(t *testing.T) {
 		expectedFilter LabelFilter
 		errorExected   bool
 	}{
-		{"foo=bar", LabelFilter{positiveLabels: [][]string{[]string{"foo", "bar"}}, negativeLabels: [][]string{}}, false},
-		{"foo!=bar", LabelFilter{positiveLabels: [][]string{}, negativeLabels: [][]string{[]string{"foo", "bar"}}}, false},
-		{"foo!=bar,baz=bat", LabelFilter{positiveLabels: [][]string{[]string{"baz", "bat"}}, negativeLabels: [][]string{[]string{"foo", "bar"}}}, false},
+		{"foo=bar", LabelFilter{positiveLabels: [][]string{{"foo", "bar"}}, negativeLabels: [][]string{}}, false},
+		{"foo!=bar", LabelFilter{positiveLabels: [][]string{}, negativeLabels: [][]string{{"foo", "bar"}}}, false},
+		{"foo!=bar,baz=bat", LabelFilter{positiveLabels: [][]string{{"baz", "bat"}}, negativeLabels: [][]string{{"foo", "bar"}}}, false},
 		{"foo", LabelFilter{positiveLabels: [][]string{}, negativeLabels: [][]string{}}, true},
 		{"foo!=bar=baz", LabelFilter{positiveLabels: [][]string{}, negativeLabels: [][]string{}}, true},
 		{"=bar", LabelFilter{positiveLabels: [][]string{}, negativeLabels: [][]string{}}, true},
@@ -988,10 +987,7 @@ func TestHelmState_SyncRepos(t *testing.T) {
 		tt := tests[i]
 		t.Run(tt.name, func(t *testing.T) {
 			for k, v := range tt.envs {
-				err := os.Setenv(k, v)
-				if err != nil {
-					t.Error("HelmState.SyncRepos() could not set env var for testing")
-				}
+				t.Setenv(k, v)
 			}
 			state := &HelmState{
 				ReleaseSetSpec: ReleaseSetSpec{
@@ -1615,6 +1611,53 @@ func TestHelmState_DiffReleases(t *testing.T) {
 	}
 }
 
+func TestHelmState_DiffFlags(t *testing.T) {
+	tests := []struct {
+		name          string
+		releases      []ReleaseSpec
+		helm          *exectest.Helm
+		wantDiffFlags []string
+	}{
+		{
+			name: "release with api version and kubeversion",
+			releases: []ReleaseSpec{
+				{
+					Name:        "releaseName",
+					Chart:       "foo",
+					KubeVersion: "1.21",
+					ApiVersions: []string{"helmfile.test/v1", "helmfile.test/v2"},
+				},
+			},
+			helm:          &exectest.Helm{},
+			wantDiffFlags: []string{"--api-versions", "helmfile.test/v1", "--api-versions", "helmfile.test/v2", "--kube-version", "1.21"},
+		},
+	}
+	for i := range tests {
+		tt := tests[i]
+		t.Run(tt.name, func(t *testing.T) {
+			state := &HelmState{
+				ReleaseSetSpec: ReleaseSetSpec{
+					Releases: tt.releases,
+				},
+				logger:         logger,
+				valsRuntime:    valsRuntime,
+				RenderedValues: map[string]interface{}{},
+			}
+			for j := range tt.releases {
+				flags, _, errs := state.flagsForDiff(tt.helm, &tt.releases[j], false, 1)
+				if errs != nil {
+					t.Errorf("unexpected error: %v", errs)
+				}
+				if !reflect.DeepEqual(flags, tt.wantDiffFlags) {
+					t.Errorf("HelmState.flagsForDiff() for [%s][%s] = %v, want %v", tt.name, tt.releases[j].Name, flags, tt.wantDiffFlags)
+				}
+			}
+
+		})
+	}
+
+}
+
 func TestHelmState_SyncReleasesCleanup(t *testing.T) {
 	tests := []struct {
 		name                    string
@@ -1798,7 +1841,7 @@ func TestHelmState_UpdateDeps(t *testing.T) {
 	var generatedDir string
 	tempDir := func(dir, prefix string) (string, error) {
 		var err error
-		generatedDir, err = ioutil.TempDir(dir, prefix)
+		generatedDir, err = os.MkdirTemp(dir, prefix)
 		if err != nil {
 			return "", err
 		}
@@ -1815,7 +1858,7 @@ generated: 2019-05-16T15:42:45.50486+09:00
 `)
 			filename := filepath.Join(generatedDir, "requirements.lock")
 			logger.Debugf("test: writing %s: %s", filename, content)
-			return ioutil.WriteFile(filename, content, 0644)
+			return os.WriteFile(filename, content, 0644)
 		}
 		return generatedDir, nil
 	}
