@@ -4,12 +4,13 @@ import (
 	"errors"
 	"fmt"
 	"hash/fnv"
-	"io/ioutil"
 	"os"
 	"path/filepath"
 	"strings"
 
 	"github.com/davecgh/go-spew/spew"
+	"github.com/helmfile/helmfile/pkg/envvar"
+	"k8s.io/apimachinery/pkg/util/rand"
 )
 
 func createTempValuesFile(release *ReleaseSpec, data interface{}) (*os.File, error) {
@@ -32,12 +33,14 @@ func tempValuesFilePath(release *ReleaseSpec, data interface{}) (*string, error)
 		panic(err)
 	}
 
-	workDir := os.Getenv("HELMFILE_TEMPDIR")
+	workDir := os.Getenv(envvar.TempDir)
 	if workDir == "" {
-		workDir, err = ioutil.TempDir(os.TempDir(), "helmfile")
-		if err != nil {
-			panic(err)
-		}
+		workDir, err = os.MkdirTemp(os.TempDir(), "helmfile")
+	} else {
+		err = os.MkdirAll(workDir, os.FileMode(0700))
+	}
+	if err != nil {
+		panic(err)
 	}
 
 	d := filepath.Join(workDir, id)
@@ -84,5 +87,5 @@ func HashObject(obj interface{}) (string, error) {
 
 	sum := fmt.Sprint(hash.Sum32())
 
-	return SafeEncodeString(sum), nil
+	return rand.SafeEncodeString(sum), nil
 }
