@@ -8,18 +8,41 @@ import (
 	"os/exec"
 	"path/filepath"
 	"reflect"
+	"strconv"
 	"strings"
 	"text/template"
 
 	"github.com/ghodss/yaml"
-	"github.com/roboll/helmfile/pkg/helmexec"
+	"github.com/helmfile/helmfile/pkg/envvar"
+	"github.com/helmfile/helmfile/pkg/helmexec"
 	"golang.org/x/sync/errgroup"
 )
 
 type Values = map[string]interface{}
 
+var DisableInsecureFeaturesErr = DisableInsecureFeaturesError{envvar.DisableInsecureFeatures + " is active, insecure function calls are disabled"}
+
+type DisableInsecureFeaturesError struct {
+	err string
+}
+
+func (e DisableInsecureFeaturesError) Error() string {
+	return e.err
+}
+
+var (
+	disableInsecureFeatures       bool
+	skipInsecureTemplateFunctions bool
+)
+
+func init() {
+	disableInsecureFeatures, _ = strconv.ParseBool(os.Getenv(envvar.DisableInsecureFeatures))
+	skipInsecureTemplateFunctions, _ = strconv.ParseBool(os.Getenv(envvar.SkipInsecureTemplateFunctions))
+}
+
 func (c *Context) createFuncMap() template.FuncMap {
 	funcMap := template.FuncMap{
+		"envExec":          c.EnvExec,
 		"exec":             c.Exec,
 		"isFile":           c.IsFile,
 		"readFile":         c.ReadFile,
@@ -35,20 +58,33 @@ func (c *Context) createFuncMap() template.FuncMap {
 		"fetchSecretValue": fetchSecretValue,
 		"expandSecretRefs": fetchSecretValues,
 	}
-	if c.preRender {
+	if c.preRender || skipInsecureTemplateFunctions {
 		// disable potential side-effect template calls
 		funcMap["exec"] = func(string, []interface{}, ...string) (string, error) {
 			return "", nil
 		}
+		funcMap["envExec"] = func(map[string]interface{}, string, []interface{}, ...string) (string, error) {
+			return "", nil
+		}
 		funcMap["readFile"] = func(string) (string, error) {
 			return "", nil
 		}
 	}
+	if disableInsecureFeatures {
+		// disable insecure functions
+		funcMap["exec"] = func(string, []interface{}, ...string) (string, error) {
+			return "", DisableInsecureFeaturesErr
+		}
+		funcMap["readFile"] = func(string) (string, error) {
+			return "", DisableInsecureFeaturesErr
+		}
+	}
 
 	return funcMap
 }
 
-func (c *Context) Exec(command string, args []interface{}, inputs ...string) (string, error) {
+// TODO: in the next major version, remove this function.
+func (c *Context) EnvExec(envs map[string]interface{}, command string, args []interface{}, inputs ...string) (string, error) {
 	var input string
 	if len(inputs) > 0 {
 		input = inputs[0]
@@ -64,8 +100,26 @@ func (c *Context) Exec(command string, args []interface{}, inputs ...string) (st
 		}
 	}
 
+	envsLen := len(envs)
+	strEnvs := make(map[string]string, envsLen)
+
+	for k, v := range envs {
+		switch v.(type) {
+		case string:
+			strEnvs[k] = fmt.Sprintf("%v", v)
+		default:
+			return "", fmt.Errorf("unexpected type of env \"%s\" in envs %v at index %s", reflect.TypeOf(v), envs, k)
+		}
+	}
+
 	cmd := exec.Command(command, strArgs...)
 	cmd.Dir = c.basePath
+	if envs != nil {
+		cmd.Env = os.Environ()
+		for k, v := range envs {
+			cmd.Env = append(cmd.Env, fmt.Sprintf("%s=%s", k, v))
+		}
+	}
 
 	g := errgroup.Group{}
 
@@ -119,6 +173,10 @@ func (c *Context) Exec(command string, args []interface{}, inputs ...string) (st
 	return string(bytes), nil
 }
 
+func (c *Context) Exec(command string, args []interface{}, inputs ...string) (string, error) {
+	return c.EnvExec(nil, command, args, inputs...)
+}
+
 func (c *Context) IsFile(filename string) (bool, error) {
 	var path string
 	if filepath.IsAbs(filename) {
@@ -145,6 +203,10 @@ func (c *Context) ReadFile(filename string) (string, error) {
 		path = filepath.Join(c.basePath, filename)
 	}
 
+	if c.readFile == nil {
+		return "", fmt.Errorf("readFile is not implemented")
+	}
+
 	bytes, err := c.readFile(path)
 	if err != nil {
 		return "", err
